==> qtools_profiler-2.2.x-dev.tar.gz: qtools_profiler/src/Routing/ProfilerRoutes.php <==
<?php

namespace Drupal\qtools_profiler\Routing;

use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Extension\ExtensionPathResolver;
use Drupal\jsonapi\ResourceType\ResourceTypeRepositoryInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\Routing\Route;

/**
 * Defines profiler routes based on module location.
 *
 * @package Drupal\qtools_profiler\Routing
 */
class ProfilerRoutes implements ContainerInjectionInterface {

  /**
   * Drupal\Core\Extension\ExtensionPathResolver.
   *
   * @var \Drupal\Core\Extension\ExtensionPathResolver
   */
  protected $extensionPathResolver;

  const PREVIEW_APP_IFRAME_ROUTE = 'qtools_profiler.preview_app_vue';

  /**
   * Instantiates a Routes object.
   */
  public function __construct(ExtensionPathResolver $extensionPathResolver) {
    $this->extensionPathResolver = $extensionPathResolver;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('extension.path.resolver'),
    );
  }

  /**
   * Generates routes for profiler app.
   *
   * @return array
   *   Routes for profiler app.
   */
  public function routes() {
    $routes = [];
    $vue_app_index_path = $this->extensionPathResolver->getPath('module', 'qtools_profiler') . '/vue-app/dist/spa/index';

    $routes[static::PREVIEW_APP_IFRAME_ROUTE] = new Route($vue_app_index_path,
      [
        '_controller' => '\Drupal\qtools_profiler\Controller\RequestReportController::previewVueApp',
        '_title' => 'QTools Profiler preview',
      ],
      [
        '_qtools_profiler_preview' => 'TRUE',
      ],
    );

    return $routes;
  }

}

==> qtools_profiler-3.0.x-dev.tar.gz: qtools_profiler/src/Routing/ProfilerRoutes.php <==
<?php

namespace Drupal\qtools_profiler\Routing;

use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Extension\ExtensionPathResolver;
use Drupal\jsonapi\ResourceType\ResourceTypeRepositoryInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\Routing\Route;

/**
 * Defines profiler routes based on module location.
 *
 * @package Drupal\qtools_profiler\Routing
 */
class ProfilerRoutes implements ContainerInjectionInterface {

  const PREVIEW_APP_IFRAME_ROUTE = 'qtools_profiler.preview_app_vue';

  /**
   * Instantiates a Routes object.
   */
  public function __construct(
    protected ExtensionPathResolver $extensionPathResolver,
  ) {
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('extension.path.resolver'),
    );
  }

  /**
   * Generates routes for profiler app.
   *
   * @return array
   *   Routes for profiler app.
   */
  public function routes() {
    $routes = [];
    $vue_app_index_path = $this->extensionPathResolver->getPath('module', 'qtools_profiler') . '/vue-app/dist/spa/index';

    $routes[static::PREVIEW_APP_IFRAME_ROUTE] = new Route($vue_app_index_path,
      [
        '_controller' => '\Drupal\qtools_profiler\Controller\RequestReportController::previewVueApp',
        '_title' => 'Qtools Profiler preview',
      ],
      [
        '_qtools_profiler_preview' => 'TRUE',
      ],
    );

    return $routes;
  }

}
